# ISA

![Mascote](https://vignette.wikia.nocookie.net/doratheexplorer/images/1/1a/Dora-Isa-looking-up-stock-art.png/revision/latest/top-crop/width/200/height/150?cb=20120705200259)

Projeto ISA (**I**sn´t **S**ql **A**nymore) é um biblioteca python que provê a inteligencia para resolução dos nomes e parsers expandindo as funcionalidades padrão do *Spark SQL*

## Install

```sh
pip install dora-isa
```
